Webmention Rocks!

# Test #10

This post has an HTTP Link header with multiple rel values.
Friday April 15, 2016 8:06am -07:00

### Reacji

The emoji below show Reacji responses, created by people posting a comment linking to this post with an `in-reply-to` property, whose text is a single emoji character.

### Likes

The profile icons below are the author photos from people who have posted a "like" post on their site, where their post links to this post with the `like-of` property.

### Reposts

The profile icons below are the author photos from people who have posted a "repost" of this post on their site, where their post links to this post with the `repost-of` property.

### Bookmarks

The profile icons below are the author photos from people who have posted a bookmark of this post on their site, where their post links to this post with the `bookmark-of` property.

### Comments

The comments below are replies to this post, and marked up their link to the post with the `in-reply-to` property.

- Ryan Barrett snarfed.org

  ### Webmention Rocks!

  Monday, April 11, 2016 10:51am -07:00
- Tantek Çelik tantek.com
  @webmentionrocks tests 1-21 passing with @Falcon using @cassisjs and link-rel-parser-php! https://github.com/indieweb/link-rel-parser-php
  Friday, April 15, 2016 4:32am -07:00

### Mentions

The mentions below linked to this post, but did not include this post's URL as an `in-reply-to` property.

- Aaron Parecki aaronparecki.com

  Here is my test post for webmention.rocks! Posted using p3k, Webmentions sent by Telegraph using the mention-client-php library.

  Test 1, Test 2, Test 3, Test 4, Test 5, Test 6, Test 7, Test 8, Test 9, Test 10, Test 11, Test 12, Test 13, Test 14, Test 15, Test 16, Test 17, Test 18, Test 19, Test 20

  Thursday, April 14, 2016 6:12pm +02:00
- http://mention-tech.appspot.com/static/logo.jpgmention.tech mention-tech.appspot.com

  ### Test page for pinging webmention.rocks from

  Monday, April 11, 2016 12:00am +00:00
- Mike Taylor bear.im

  ### Testing Webmention.rocks

  Sunday, April 10, 2016 10:48pm +00:00